pub enum CommotError {
FileError(Error),
ArgNotFound(String),
}Expand description
Simple errors, like FileError which is converted from [std::io::Error]
ArgNotFound error is given when you run the commot command without giving the file or when the required arg is not
provided by the user.
Variants