Structs
- File
Data - File
Metadata - File
Size - Reader
- File Reader
Enums
- File
Size Type FileSizeTypeThis enum has all the size types which are storing the size inside them.
FileSizeType
This enum has all the size types which are storing the size inside them.